@@ -30,10 +30,26 @@ def read_file(filename, isbin=False, encoding="utf-8"):
         return f.read()
 
 
-def read_lines(filename, encoding="utf-8"):
+def write_lines(
+    filename, lines: list[str], encoding="utf-8", newline="\n", newlineinlines=False
+):
+    "save lines to file"
+    with open(filename, mode="wt", encoding=encoding) as f:
+        if newlineinlines:
+            f.writelines(lines)
+        else:
+            for line in lines:
+                f.write(line)
+                f.write(newline)
+
+
+def read_lines(filename, encoding="utf-8", keepends=False):
     "read lines from file"
     with open(filename, mode="r", encoding=encoding) as f:
-        return f.readlines()
+        if keepends:
+            return f.readlines()
+        else:
+            return f.read().splitlines(keepends)
 
 
 def copy_file(src, dst):
